NetworkResponseErrorType enum

Inheritance
Available extensions

Values

socket → const NetworkResponseErrorType
exception → const NetworkResponseErrorType
badRequest → const NetworkResponseErrorType
timeout → const NetworkResponseErrorType
responseEmpty → const NetworkResponseErrorType
didNotSucceed → const NetworkResponseErrorType
conflict → const NetworkResponseErrorType
unauthorized → const NetworkResponseErrorType
forbidden → const NetworkResponseErrorType
notFound → const NetworkResponseErrorType
unprocessableEntity → const NetworkResponseErrorType
serverError → const NetworkResponseErrorType
badGateway → const NetworkResponseErrorType
serviceUnavailable → const NetworkResponseErrorType
gatewayTimeout → const NetworkResponseErrorType
networkError → const NetworkResponseErrorType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NetworkResponseErrorType>
A constant List of the values in this enum, in order of their declaration.